@@ -1,4 +1,7 @@
+__version__ = "0.0.11"
 __all__ = [
+    "defaultchecks",
+    "warningchecks",
     "allchecks",
     "checkrsa",
     "checkpubkey",
@@ -10,6 +13,8 @@ __all__ = [
     "scanssh",
 ]
 from .checks import (
+    defaultchecks,
+    warningchecks,
     allchecks,
     checkrsa,
     checkpubkey,
